@@ -1,8 +1,8 @@
 """
-Fynx Observable - Core Reactive Value Implementation
+FynX Observable - Core Reactive Value Implementation
 ====================================================
 
-This module provides the fundamental building blocks for reactive programming in Fynx:
+This module provides the fundamental building blocks for reactive programming in FynX:
 
 - **Observable**: The core class representing a reactive value that can be observed
   for changes and automatically notifies dependents.
@@ -16,23 +16,30 @@ This module provides the fundamental building blocks for reactive programming in
 - **ConditionalObservable**: Creates observables that only trigger reactions under
   specific conditions.
 
-The Observable class forms the foundation of Fynx's reactivity system, providing
+The Observable class forms the foundation of FynX's reactivity system, providing
 transparent dependency tracking and automatic change propagation.
 """
 
-from typing import TYPE_CHECKING, Callable, Generic, List, Optional, Set, Type, TypeVar
-
-if TYPE_CHECKING:
-    from .merged import MergedObservable
-    from .conditional import ConditionalObservable
+from typing import (
+    Callable,
+    Generic,
+    List,
+    Optional,
+    Set,
+    Type,
+    TypeVar,
+)
 
 from ..registry import _all_reactive_contexts, _func_to_contexts
-from .descriptors import SubscriptableDescriptor
+from .interfaces import Conditional, Mergeable
+from .interfaces import Observable as ObservableInterface
+from .interfaces import ReactiveContext as ReactiveContextInterface
+from .operators import OperatorMixin
 
 T = TypeVar("T")
 
 
-class ReactiveContext:
+class ReactiveContext(ReactiveContextInterface):
     """
     Execution context for reactive functions with automatic dependency tracking.
 
@@ -49,9 +56,23 @@ class ReactiveContext:
     The context uses a stack-based approach to handle nested reactive functions,
     ensuring that dependencies are tracked correctly even in complex scenarios.
 
+    Attributes:
+        func (Callable): The reactive function to execute
+        original_func (Callable): The original user function (for unsubscribe)
+        subscribed_observable (Observable): The observable this context is subscribed to
+        dependencies (Set[Observable]): Set of observables accessed during execution
+        is_running (bool): Whether the context is currently executing
+
     Note:
-        This class is typically managed automatically by Fynx's decorators and
+        This class is typically managed automatically by FynX's decorators and
         observable operations. Direct instantiation is usually not needed.
+
+    Example:
+        ```python
+        # Usually created automatically by @reactive decorator
+        context = ReactiveContext(my_function, my_function, some_observable)
+        context.run()  # Executes function and tracks dependencies
+        ```
     """
 
     def __init__(
@@ -114,11 +135,11 @@ class ReactiveContext:
         self.dependencies.clear()
 
 
-class Observable(Generic[T]):
+class Observable(ObservableInterface[T], OperatorMixin):
     """
     A reactive value that automatically notifies dependents when it changes.
 
-    Observable is the core primitive of Fynx's reactivity system. It wraps a value
+    Observable is the core primitive of FynX's reactivity system. It wraps a value
     and provides transparent reactive behavior - when the value changes, all
     dependent computations and reactions are automatically notified and updated.
 
@@ -128,20 +149,40 @@ class Observable(Generic[T]):
     - **Change Notification**: Notifies all observers when the value changes
     - **Type Safety**: Generic type parameter ensures type-safe operations
     - **Lazy Evaluation**: Computations only re-run when actually needed
+    - **Circular Dependency Detection**: Prevents infinite loops at runtime
 
     Observable implements various magic methods (`__eq__`, `__str__`, etc.) to
     behave like its underlying value in most contexts, making it easy to use
     in existing code without modification.
 
+    Attributes:
+        key (Optional[str]): Unique identifier for debugging and serialization
+        _value (Optional[T]): The current wrapped value
+        _observers (Set[Callable]): Set of observer functions
+
+    Class Attributes:
+        _current_context (Optional[ReactiveContext]): Current reactive execution context
+        _context_stack (List[ReactiveContext]): Stack of nested reactive contexts
+
+    Args:
+        key: A unique identifier for this observable (used for debugging).
+             If None, will be set to "<unnamed>" and updated in __set_name__.
+        initial_value: The initial value to store. Can be any type.
+
+    Raises:
+        RuntimeError: If a circular dependency is detected during value updates.
+
     Example:
         ```python
-        from fynx import observable
+        from fynx.observable import Observable
 
         # Create an observable
-        counter = observable("counter", 0)
+        counter = Observable("counter", 0)
 
-        # Direct access
+        # Direct access (transparent behavior)
         print(counter.value)  # 0
+        print(counter == 0)   # True
+        print(str(counter))   # "0"
 
         # Subscribe to changes
         def on_change():
@@ -153,7 +194,13 @@ class Observable(Generic[T]):
 
     Note:
         While you can create Observable instances directly, it's often more
-        convenient to use the `observable()` descriptor in Store classes.
+        convenient to use the `observable()` descriptor in Store classes for
+        better organization and automatic serialization support.
+
+    See Also:
+        Store: For organizing observables into reactive state containers
+        computed: For creating derived values from observables
+        reactive: For creating reactive functions that respond to changes
     """
 
     # Class variable to track the current reactive context
@@ -162,21 +209,47 @@ class Observable(Generic[T]):
     # Stack of reactive contexts being computed (for proper cycle detection)
     _context_stack: List["ReactiveContext"] = []
 
-    def __init__(self, key: str, initial_value: Optional[T] = None) -> None:
+    def __init__(
+        self, key: Optional[str] = None, initial_value: Optional[T] = None
+    ) -> None:
         """
         Initialize an observable value.
 
         Args:
-            key: A unique identifier for this observable (used for serialization)
+            key: A unique identifier for this observable (used for serialization).
+                 If None, will be set to "<unnamed>" and updated in __set_name__.
             initial_value: The initial value to store
         """
-        self.key = key
+        self.key = key or "<unnamed>"
         self._value = initial_value
         self._observers: Set[Callable] = set()
 
     @property
     def value(self) -> Optional[T]:
-        """Get the current value of this observable."""
+        """
+        Get the current value of this observable.
+
+        Accessing the value property automatically registers this observable
+        as a dependency if called within a reactive context (computation or reaction).
+
+        Returns:
+            The current value stored in this observable, or None if not set.
+
+        Note:
+            This property is tracked by the reactive system. Use it instead of
+            accessing _value directly to ensure proper dependency tracking.
+
+        Example:
+            ```python
+            obs = Observable("counter", 5)
+            print(obs.value)  # 5
+
+            # In a reactive context, this creates a dependency
+            @reactive(obs)
+            def print_value(val):
+                print(f"Value: {val}")
+            ```
+        """
         # Track dependency if we're in a reactive context
         if Observable._current_context is not None:
             Observable._current_context.add_dependency(self)
@@ -186,8 +259,33 @@ class Observable(Generic[T]):
         """
         Set the value and notify all observers if the value changed.
 
+        This method updates the observable's value and triggers change notifications
+        to all registered observers. The update only occurs if the new value is
+        different from the current value (using != comparison).
+
+        Circular dependency detection is performed to prevent infinite loops where
+        a computation tries to modify one of its own dependencies.
+
         Args:
-            value: The new value to set
+            value: The new value to set. Can be any type compatible with the
+                   observable's generic type parameter.
+
+        Raises:
+            RuntimeError: If setting this value would create a circular dependency
+                         (e.g., a computed value trying to modify its own input).
+
+        Example:
+            ```python
+            obs = Observable("counter", 0)
+            obs.set(5)  # Triggers observers if value changed
+
+            # No change, no notification
+            obs.set(5)  # Same value, observers not called
+            ```
+
+        Note:
+            Equality is checked using `!=` operator, so custom objects should
+            implement proper equality comparison if needed.
         """
         # Check for circular dependency: check if the current context
         # is computing a value that depends on this observable
@@ -235,11 +333,33 @@ class Observable(Generic[T]):
         """
         Subscribe a function to react to changes in this observable.
 
+        The subscribed function will be called whenever the observable's value changes.
+
         Args:
-            func: The function to call when this observable changes.
+            func: A callable that accepts one argument (the new value).
+                  The function will be called whenever the observable's value changes.
 
         Returns:
             This observable instance for method chaining.
+
+        Example:
+            ```python
+            def on_change(new_value):
+                print(f"Observable changed to: {new_value}")
+
+            obs = Observable("counter", 0)
+            obs.subscribe(on_change)
+
+            obs.set(5)  # Prints: "Observable changed to: 5"
+            ```
+
+        Note:
+            The function is called only when the observable's value changes.
+            It is not called immediately upon subscription.
+
+        See Also:
+            unsubscribe: Remove a subscription
+            reactive: Decorator-based subscription with automatic dependency tracking
         """
 
         def single_reaction():
@@ -283,7 +403,22 @@ class Observable(Generic[T]):
     def _dispose_subscription_contexts(
         func: Callable, filter_predicate: Optional[Callable] = None
     ) -> None:
-        """Dispose of subscription contexts for a function with optional filtering."""
+        """
+        Dispose of subscription contexts for a function with optional filtering.
+
+        This internal method finds and cleans up ReactiveContext instances associated
+        with a given function. It's used by unsubscribe() methods to properly clean up
+        reactive subscriptions.
+
+        Args:
+            func: The function whose subscription contexts should be disposed
+            filter_predicate: Optional predicate function to filter which contexts to dispose.
+                            Should accept a ReactiveContext and return bool.
+
+        Note:
+            This is an internal method used by the reactive system.
+            Direct use is not typically needed.
+        """
         if func not in _func_to_contexts:
             return
 
@@ -305,36 +440,172 @@ class Observable(Generic[T]):
 
     # Magic methods for transparent behavior
     def __bool__(self) -> bool:
-        """Boolean conversion returns whether the value is truthy."""
+        """
+        Boolean conversion returns whether the value is truthy.
+
+        This allows observables to be used directly in boolean contexts
+        (if statements, boolean operations) just like regular values.
+
+        Returns:
+            True if the wrapped value is truthy, False otherwise.
+
+        Example:
+            ```python
+            obs = Observable("flag", True)
+            if obs:  # Works like if obs.value
+                print("Observable is truthy")
+
+            obs.set(0)  # False
+            if not obs:  # Works like if not obs.value
+                print("Observable is falsy")
+            ```
+        """
         return bool(self._value)
 
     def __str__(self) -> str:
-        """String representation of the value."""
+        """
+        String representation of the wrapped value.
+
+        Returns the string representation of the current value,
+        enabling observables to be used seamlessly in string contexts.
+
+        Returns:
+            String representation of the wrapped value.
+
+        Example:
+            ```python
+            obs = Observable("name", "Alice")
+            print(f"Hello {obs}")  # Prints: "Hello Alice"
+            message = "User: " + obs  # Works like "User: " + obs.value
+            ```
+        """
         return str(self._value)
 
     def __repr__(self) -> str:
-        """Developer representation of this observable."""
+        """
+        Developer representation showing the observable's key and current value.
+
+        Returns:
+            A string representation useful for debugging and development.
+
+        Example:
+            ```python
+            obs = Observable("counter", 42)
+            print(repr(obs))  # Observable('counter', 42)
+            ```
+        """
         return f"Observable({self.key!r}, {self._value!r})"
 
     def __eq__(self, other: object) -> bool:
-        """Equality comparison with another value or observable."""
+        """
+        Equality comparison with another value or observable.
+
+        Compares the wrapped values for equality. If comparing with another
+        Observable, compares their wrapped values.
+
+        Args:
+            other: Value or Observable to compare with
+
+        Returns:
+            True if the values are equal, False otherwise.
+
+        Example:
+            ```python
+            obs1 = Observable("a", 5)
+            obs2 = Observable("b", 5)
+            regular_val = 5
+
+            obs1 == obs2      # True (both wrap 5)
+            obs1 == regular_val  # True (observable equals regular value)
+            obs1 == 10        # False (5 != 10)
+            ```
+        """
         if isinstance(other, Observable):
             return self._value == other._value
         return self._value == other
 
     def __hash__(self) -> int:
-        """Hash based on object identity, not value (values may be unhashable)."""
+        """
+        Hash based on object identity, not value.
+
+        Since values may be unhashable (like dicts, lists), observables
+        hash based on their object identity rather than their value.
+
+        Returns:
+            Hash of the observable's object identity.
+
+        Note:
+            This means observables with the same value will not be
+            considered equal for hashing purposes, only identical objects.
+
+        Example:
+            ```python
+            obs1 = Observable("a", [1, 2, 3])
+            obs2 = Observable("b", [1, 2, 3])
+
+            # These will have different hashes despite same value
+            hash(obs1) != hash(obs2)  # True
+
+            # But identical objects hash the same
+            hash(obs1) == hash(obs1)  # True
+            ```
+        """
         return id(self)
 
     # Descriptor protocol for use as class attributes
     def __set_name__(self, owner: Type, name: str) -> None:
-        """Called when assigned to a class attribute."""
-        # Check if owner is a Store class - if so, let StoreMeta handle the conversion
-        from .store import Store
+        """
+        Called when this Observable is assigned to a class attribute.
 
-        if issubclass(owner, Store):
+        This method implements the descriptor protocol to enable automatic
+        conversion of Observable instances to appropriate descriptors based
+        on the owning class type.
+
+        For Store classes, the conversion is handled by StoreMeta metaclass.
+        For other classes, converts to SubscriptableDescriptor for class-level
+        observable behavior.
+
+        Args:
+            owner: The class that owns this attribute
+            name: The name of the attribute being assigned
+
+        Note:
+            This method is called automatically by Python when an Observable
+            instance is assigned to a class attribute. It modifies the class
+            to use the appropriate descriptor for reactive behavior.
+
+        Example:
+            ```python
+            class MyClass:
+                obs = Observable("counter", 0)  # __set_name__ called here
+
+            # Gets converted to a descriptor automatically
+            instance = MyClass()
+            print(instance.obs)  # Uses descriptor
+            ```
+        """
+        # Update key if it was defaulted to "<unnamed>"
+        if self.key == "<unnamed>":
+            # Check if this is a computed observable by checking for the _is_computed attribute
+            if getattr(self, "_is_computed", False):
+                self.key = f"<computed:{name}>"
+            else:
+                self.key = name
+
+        # Skip processing for computed observables - they should remain as-is
+        if getattr(self, "_is_computed", False):
             return
 
+        # Check if owner is a Store class - if so, let StoreMeta handle the conversion
+        try:
+            from .store import Store
+
+            if issubclass(owner, Store):
+                return
+        except ImportError:
+            # If store module is not available, continue with normal processing
+            pass
+
         # For non-Store classes, convert to a SubscriptableDescriptor
         # that will create class-level observables
         from .descriptors import SubscriptableDescriptor
@@ -348,106 +619,3 @@ class Observable(Generic[T]):
 
         # Remove this instance since it's being replaced
         # The descriptor will create the actual Observable when accessed
-
-    def __or__(self, other: "Observable") -> "MergedObservable[T]":
-        """
-        Combine this observable with another using the | operator.
-
-        This creates a merged observable that contains a tuple of both values
-        and updates automatically when either observable changes.
-
-        Args:
-            other: Another Observable to combine with
-
-        Returns:
-            A MergedObservable containing both values as a tuple
-
-        Example:
-            ```python
-            combined = obs1 | obs2  # Creates MergedObservable((obs1.value, obs2.value))
-            combined2 = combined | obs3  # Creates MergedObservable((obs1.value, obs2.value, obs3.value))
-            ```
-        """
-        from .merged import MergedObservable  # Import here to avoid circular import
-
-        if isinstance(other, MergedObservable):
-            # If other is already merged, combine our observable with its sources
-            return MergedObservable(self, *other._source_observables)
-        else:
-            # Standard case: combine two regular observables
-            return MergedObservable(self, other)
-
-    def __rshift__(self, func: Callable) -> "Observable":
-        """
-        Chain a transformation function to create a new computed observable using >>.
-
-        This is the functorial map operation: it applies a function to this observable,
-        creating a new observable with the transformed values.
-
-        Args:
-            func: Function to apply to the observable's value(s).
-                  For merged observables, receives the tuple values as separate arguments.
-
-        Returns:
-            A new Observable with computed values
-
-        Examples:
-            ```python
-            # Single observable
-            doubled = obs >> (lambda x: x * 2)
-
-            # Merged observable
-            combined = obs1 | obs2
-            result = combined >> (lambda a, b: a + b)
-
-            # Chaining
-            final = obs >> func1 >> func2 >> func3
-            ```
-        """
-        from .operators import rshift_operator
-
-        return rshift_operator(self, func)
-
-    def __and__(self, condition: "Observable[bool]") -> "ConditionalObservable[T]":
-        """
-        Create a conditional observable using the & operator.
-
-        This creates a conditional observable that only emits values when the condition
-        (and any additional conditions) are all True.
-
-        Args:
-            condition: A boolean Observable that must be True for emission
-
-        Returns:
-            A ConditionalObservable that filters updates based on the condition
-
-        Example:
-            ```python
-            # Only emit when image is uploaded AND valid
-            valid_image = uploaded_image & is_valid_image
-
-            # Chain multiple conditions
-            ready_to_process = uploaded_image & is_valid_image & ~is_processing
-            ```
-        """
-        from .operators import and_operator
-
-        return and_operator(self, condition)
-
-    def __invert__(self) -> "Observable[bool]":
-        """
-        Create a negated boolean observable using the ~ operator.
-
-        This creates a computed observable that returns the logical negation
-        of the current observable's boolean value.
-
-        Returns:
-            An Observable[bool] with the negated value
-
-        Example:
-            ```python
-            is_not_processing = ~is_processing  # True when is_processing is False
-            ready_to_process = is_valid & ~is_processing
-            ```
-        """
-        return self >> (lambda x: not x)
